@@ -1,53 +1,3 @@
-#' NNS PDF
-#'
-#' This function generates an empirical PDF using \link{dy.dx} on \link{NNS.CDF}.
-#'
-#' @param variable a numeric vector.
-#' @param degree integer; \code{(degree = 0)} is frequency, \code{(degree = 1)} (default) is area.
-#' @param target a numeric range of values [a,b] where a < b.  \code{NULL} (default) uses the \code{variable} min and max observations respectively.
-#' @param bins integer; \code{NULL} Selects number of bins.  Bin width defaults to \code{density(x)$bw}.
-#' @param plot logical; plots PDF.
-#' @return Returns a data.table containing the intervals used and resulting PDF of the variable.
-#' @author Fred Viole, OVVO Financial Systems
-#' @references Viole, F. and Nawrocki, D. (2013) "Nonlinear Nonparametric Statistics: Using Partial Moments"
-#' \url{https://www.amazon.com/dp/1490523995/ref=cm_sw_su_dp}
-#' @examples
-#' \dontrun{
-#' set.seed(123)
-#' x <- rnorm(100)
-#' NNS.PDF(x)
-#'
-#' ## Custom target range
-#' NNS.PDF(x, target = c(-5, 5))
-#' }
-#' @export
-
-
-NNS.PDF <- function(variable, degree = 1, target = NULL, bins = NULL , plot = TRUE){
-  if(any(class(variable)%in%c("tbl","data.table"))){
-    variable <- as.vector(unlist(variable))
-  }
-  if(is.null(target)){
-    target <- sort(variable)
-  }
-  
-  # d/dx approximation
-  if(is.null(bins)){
-    bins <- density(variable)$bw
-    tgt <- seq(min(target), max(target), bins)
-  } else {
-    d.dx <- (abs(max(target)) + abs(min(target))) / bins
-    tgt <- seq(min(target), max(target), d.dx)
-  }
-  CDF <- NNS.CDF(variable, plot = FALSE, degree = degree)$Function
-  PDF <- pmax(dy.dx(unlist(CDF[,1]), unlist(CDF[,2]), eval.point = tgt)$First, 0)
-  if(plot){
-    plot(tgt, PDF, col = 'steelblue', type = 'l', lwd = 3, xlab = "X", ylab = "Density")
-  }
-  return(data.table::data.table(cbind("Intervals" = tgt, PDF)))
-}
-
-
 #' NNS CDF
 #'
 #' This function generates an empirical CDF using partial moment ratios \link{LPM.ratio}, and resulting survival, hazard and cumulative hazard functions.
